﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.UI.WebControls;
using Dynamicweb.Samples.Web.Model;

namespace Dynamicweb.Samples.Web.CustomModules.DvkArticles.Admin
{
	public partial class AddEditArticle : System.Web.UI.Page
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			InitializeStylesGallery();

			if (!Page.IsPostBack && Id > 0)
			{
				BindData();
			}
		}

		private void InitializeStylesGallery()
		{
			Dictionary<string, string> Styles = new Dictionary<string, string>()
			{
				{"Normal", "Normal"},
				{"HighContrast", "High Contrast"},
				{"Heading1", "Heading 1"},
				{"Heading2", "Heading 2"},
				{"Heading3", "Heading 3"},
				{"Paragraph", "Paragraph"},
				{"Introduction", "Introduction"},
				{"Code", "Code"}
			};

			// Binding data
			if (!Page.IsPostBack)
			{
				stylesList.DataSource = Styles;
				stylesList.DataBind();
			}
		}

		/// <summary>
		/// Create a new or update an existing Article in the database and send the user back to the main Articles page.
		/// </summary>
		protected void SaveButton_Click(object sender, EventArgs e)
		{
			//TODO Hook up to new UI Save buttons
			Article article;
			using (CustomModulesSamplesEntities db = new CustomModulesSamplesEntities())
			{
				if (Id > 0)
				{
					article = db.Articles.Include("Category").Where(a => a.Id == Id).FirstOrDefault();
				}
				else
				{
					article = new Article { CreateDateTime = DateTime.Now };
					db.AddToArticles(article);
				}
				article.Body = Body.Text;

				int categoryId = Convert.ToInt32(CategoryList.SelectedValue);
				article.Category = db.Categories.Where(c => c.Id == categoryId).FirstOrDefault(); // Will be easier with EF for .NET 4 where you can use foreign keys
				article.PublicationDateFrom = PublishFrom.Date;
				article.PublicationDateTo = PublishTo.Date;
				article.SeoDescription = SeoDescription.Text;
				article.Summary = Summary.Text;
				article.Title = ArticleTitle.Text;
				article.UpdateDateTime = DateTime.Now;
				db.SaveChanges();
				EndEditing();
			}
		}

		/// <summary>
		/// Gets an Article from the database and prepopulates the form controls.
		/// </summary>
		private void BindData()
		{
			using (CustomModulesSamplesEntities db = new CustomModulesSamplesEntities())
			{
				Article article = db.Articles.Include("Category").Where(a => a.Id == Id).FirstOrDefault();
				if (article != null)
				{
					ArticleTitle.Text = article.Title;
					Summary.Text = article.Summary;
					SeoDescription.Text = article.SeoDescription;
					Body.Text = article.Body;
					PublishFrom.Date = article.PublicationDateFrom;
					PublishTo.Date = article.PublicationDateTo;
					CategoryList.DataBind();
					ListItem listItem = CategoryList.Items.FindByValue(article.Category.Id.ToString());
					if (listItem != null)
					{
						listItem.Selected = true;
					}
				}
				else
				{
					EndEditing();
				}
			}
		}

		/// <summary>
		/// Redirects to the main article page.
		/// </summary>
		private void EndEditing()
		{
			Response.Redirect("Default.aspx");
		}

		/// <summary>
		/// Tries to get the ID from the Query String and return it. Otherwise, it returns 0.
		/// </summary>
		private int Id
		{
			get
			{
				int id;
				string temp = Request.QueryString["Id"];
				if (!string.IsNullOrEmpty(temp) && int.TryParse(temp, out id))
				{
					return id;
				}
				return 0;
			}
		}
	}
}