﻿using System;
using System.Linq;
using Dynamicweb.Extensibility;
using Dynamicweb.Frontend;
using Dynamicweb.Samples.Web.Model;

namespace Dynamicweb.Samples.Web.DvkArticles
{
	[AddInName("DvkArticles")]
	public class Frontend : CustomModuleBase
	{
		public override string GetContent()
		{
			if (Base.ChkInteger(Base.Request("ArticleId")) == 0)
			{
				int categoryId = Base.ChkInteger(Base.Request("CategoryId"));

				// Note: the ArticleList.html template is currently incompatible with the code below, so you may get an empty page.
				Dynamicweb.Templatev2.Template listTemplate = new Dynamicweb.Templatev2.Template("DvkArticles/" + ListTemplate);

				using (CustomModulesSamplesEntities db = new CustomModulesSamplesEntities())
				{
					if (categoryId > 0)
					{
						var category = db.Categories.Include("Articles").Where(c => c.Id == categoryId).FirstOrDefault();
						if (category == null)
						{
							return "Unknown category";
						}

						listTemplate.SetTag("CategoryName", category.Description);
						Dynamicweb.Templatev2.Template articleTemplate = listTemplate.GetLoop("ItemsLoop");
						foreach (var article in category.Articles.Where(c => (c.PublicationDateFrom <= DateTime.Now && c.PublicationDateTo >= DateTime.Now && !c.Deleted)).OrderBy(c => c.Title))
						{
							articleTemplate.SetTag("Title", article.Title);
							string url = string.Format("Default.aspx?ID={0}&ArticleId={1}", Pageview.ID.ToString(), article.Id.ToString());
							string link = SearchEngineFriendlyURLs.getSearchFriendlyUrl(url, article.Title);
							articleTemplate.SetTag("DetailsUrl", link);
							articleTemplate.CommitLoop();
						}
					}
					Dynamicweb.Templatev2.Template categoryLoop = listTemplate.GetLoop("Categories");
					foreach (Category category in db.Categories)
					{
						categoryLoop.SetTag("Id", category.Id);
						categoryLoop.SetTag("Description", category.Description);
						categoryLoop.CommitLoop();
					}
					return listTemplate.Output();
				}
			}
			else
			{
				int articleId = Base.ChkInteger(Base.Request("ArticleId"));
				using (CustomModulesSamplesEntities db = new CustomModulesSamplesEntities())
				{
					var article = db.Articles.Include("Category").Where(a =>
						a.PublicationDateFrom <= DateTime.Now
						&& a.PublicationDateTo >= DateTime.Now
						&& !a.Deleted
						&& a.Id == articleId).FirstOrDefault();

					if (article != null)
					{
						Dynamicweb.Templatev2.Template detailsTemplate = new Dynamicweb.Templatev2.Template("DvkArticles/" + Properties.Values["DetailsTemplate"].ToString());
						detailsTemplate.SetTag("Title", article.Title);
						detailsTemplate.SetTag("Body", article.Body);
						detailsTemplate.SetTag("CategoryName", article.Category.Description);
						detailsTemplate.SetTag("CreateDateTime", article.CreateDateTime);
						if (article.CreateDateTime < article.UpdateDateTime)
						{
							detailsTemplate.SetTag("UpdateDateTime", article.UpdateDateTime);
						}
						detailsTemplate.SetTag("Id", article.Id);
						detailsTemplate.SetTag("Summary", article.Summary);
						Pageview.Meta.MetaTags["Description"] = article.SeoDescription;
						return detailsTemplate.Output();
					}
					else
					{
						return "This article could not be found.";
					}
				}
			}
		}

		public string ListTemplate
		{
			get
			{
				object temp = Properties.Values["ListTemplate"];
				if (temp != null && !string.IsNullOrEmpty(temp.ToString()))
				{
					return temp.ToString();
				}
				// Optional: return a default value
				// return "ArticleList.html";

				// Alternatively, throw an exception
				throw new ArgumentNullException("ListTemplate", "No ListTemplate has been set in the module's Edit page.");
			}
		}

		public string DetailsTemplate
		{
			get
			{
				object temp = Properties.Values["DetailsTemplate"];
				if (temp != null && !string.IsNullOrEmpty(temp.ToString()))
				{
					return temp.ToString();
				}
				// Return a default value
				return "ArticleDetails.html";
			}
		}

	}
}